##  Changing and Opening Linked Fact Sheets
To change the linked fact sheet, you can unlink a fact sheet and then link a new one again or change the linked fact sheet by doing the following:
  1. Right-click on the already linked shape and select Change linked fact sheet.
  2. From the fact sheet quick search, you can either scroll to look for another fact sheet available in your workspace or start typing to find the fact sheet you need.
  3. After selecting another fact sheet from the quick search, the label and color will be updated with the newly linked fact sheet.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c07ae7a441014b718860e83c5826f_LowRes.gif)
Linking a fact sheet to a shape will allow you to open the fact sheet from the canvas. The linked fact sheet can be opened by right-clicking on the shape and selecting Open fact sheet. The fact sheet will open in a new tab.
